pyscenarios: Python Scenario Generator
======================================

This package offers several modules used in Monte Carlo simulations:

- Gaussian Copula, Student T* Copula and IT Copula samples generators
- Sobol series generator
- Tail dependence measures

All modules fully support and are optimized for `Dask <https://dask.org>`_
and are compatible with `Dask distributed <http://distributed.dask.org>`_.


Index
-----

.. toctree::

   installing
   api
   whats-new

License
-------

pyscenarios is available under the open source
`Apache License <http://www.apache.org/licenses/LICENSE-2.0.html>`_.

Joe/Kuo direction numbers for Sobol are available under a bespoke
`BSD-style license <https://web.maths.unsw.edu.au/~fkuo/sobol/licence>`_.
